@@ -9,3 +9,8 @@ __copyright__ = 'Python Software Foundation'
 from formatters import XMLLayout
 from handlers import RawSocketHandler
 from properties import Log4jProperties
+
+def LogfacesFormatter(**kwds):
+    props = Log4jProperties(**kwds)
+    return XMLLayout(properties=props)
+
